/*
 * Java Othello Openings Applet
 * Copyright (C) 2000 Bill Lorton
 * email: hogarth1@yahoo.com
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

import java.io.*;

/**
 *
 * A hierarchical tree node that contains opening move data.
 *
 * @version 1.00
 * @author Bill Lorton
 *
 */
class OTNode extends TreeNode {
  private Opening _data;
  private String  _move;

  /**
   *
   * The OTNode constructor.
   *
   */
  public OTNode() { _move  = ""; _data  = null; }


  /**
   *
   * Sets the opening data.
   *
   * @param data the opening to associate with this node
   *
   */
  public void setData(Opening data) { _data = data; }


  /**
   *
   * Sets the single move associated with this node.
   *
   * @param move a single move which is a two character sequence
   *
   */
  public void setMove(String move) { _move = move; }


  /**
   *
   * Gets the opening data associated with this node.
   *
   * @return the opening data for this node
   *
   */
  public Opening data() { return _data; }


  /**
   *
   * Gets the move associated with this node.
   *
   * @return the single move for this node
   *
   */
  public String  move() { return _move; }


  /**
   *
   * For debugging purposes only.
   *
   */
  public void println()
  {
    System.out.print("this:  ");
    System.out.print(this);
    System.out.print("  move:  "+_move+"  data:  ");
    System.out.print(_data);
    System.out.print("  next:  ");
    System.out.print(next());
    System.out.print("  child:  ");
    System.out.println(child());
  }
}


